package org.jetbrains.intellij.sharedIndexes.local

import com.intellij.indexing.shared.cdn.CdnUrls
import java.nio.file.Files
import java.nio.file.Paths

class Args(args: Array<String>) : CdnUrls {

  private fun arg(args: Array<String>, key: String, default: String? = null): String {
    val keyValue = args.find { it.startsWith("--$key=") }
    if (keyValue == null) {
      requireNotNull(default) { "Required option '--$key=' is not specified " }
      return default
    }
    return keyValue.substringAfter("--$key=").trim()
  }

  val indexesDir = arg(args, "indexes-dir").let { Paths.get(it) }

  val baseUrl = arg(args, "url").trim().removeSuffix("/").trim()

  override fun downloadUrl(key: String): String = listOf(baseUrl, key)
    .map { it.trim('/') }
    .filter { it.isNotBlank() }
    .joinToString("/")

  companion object {
    fun usage() {
      println("Shared Indexes List Generator")
      println("Usage:")
      println(" [tool] \\")
      println("    --indexes-dir=<dir of the indexes> \\")
      println("    --url=<base URL>")
      println()
    }
  }

}