package org.jetbrains.intellij.sharedIndexes.local

import com.intellij.indexing.shared.cdn.CdnUploadEntry
import java.nio.file.Files
import java.nio.file.Path

fun addFiles(indexesDir: Path, files: Iterable<CdnUploadEntry>) {
  for (newEntry in files) {
    val targetPath = indexesDir.resolve(newEntry.key.replace("/", indexesDir.fileSystem.separator))
    if (Files.exists(targetPath)) {
      if (newEntry.timestamp == Files.getLastModifiedTime(targetPath).toInstant()) {
        println("File ${newEntry.key} is up-to-date")
        continue
      }
      println("Updating ${newEntry.key} in $indexesDir...")
    } else {
      Files.createDirectories(targetPath.parent)
      println("Copying ${newEntry.key} to $indexesDir...")
    }

    newEntry.inputStream().use { input ->
      Files.newOutputStream(targetPath).buffered().use { output ->
        input.copyTo(output)
      }
    }
  }
}
