package org.jetbrains.intellij.sharedIndexes.local

import com.intellij.indexing.shared.cdn.CdnSnapshotEntry
import com.intellij.indexing.shared.cdn.formatSize
import java.io.IOException
import java.nio.file.FileVisitResult
import java.nio.file.Files
import java.nio.file.Path
import java.nio.file.SimpleFileVisitor
import java.nio.file.attribute.BasicFileAttributes

fun wipeFiles(indexesDir: Path, toRemove: Collection<CdnSnapshotEntry>) {
  if (toRemove.isEmpty()) return
  val totalSize = toRemove.map { it.contentLength }.sum()
  println("Removing ${toRemove.size} items (total size: ${formatSize(totalSize)}")
  for (entry in toRemove) {
    println("  Removing ${entry.key} with size ${formatSize(entry.contentLength)}")
    val file = indexesDir.resolve(entry.key.replace("/", indexesDir.fileSystem.separator))
    if (Files.isDirectory(file)) {
      file.removeDirectory()
    }
    else if (Files.exists(file)) {
      Files.delete(file)
    }
  }
}

private fun Path.removeDirectory() {
  Files.walkFileTree(this, object : SimpleFileVisitor<Path>() {
    @Throws(IOException::class)
    override fun visitFile(file: Path, attrs: BasicFileAttributes): FileVisitResult {
      Files.delete(file)
      return FileVisitResult.CONTINUE
    }

    @Throws(IOException::class)
    override fun postVisitDirectory(dir: Path, exc: IOException?): FileVisitResult {
      Files.delete(dir)
      return FileVisitResult.CONTINUE
    }
  })
}

