package org.jetbrains.intellij.sharedIndexes.local

import com.intellij.indexing.shared.cdn.emptyCdnSnapshot
import com.intellij.indexing.shared.cdn.localCdnSnapshot
import com.intellij.indexing.shared.cdn.planCdnUpload
import kotlin.system.exitProcess

fun main(argsArray: Array<String>) {
  println("Running the 'cdn-layout-tool' tool #$toolVersion")
  val args = try {
    Args(argsArray)
  }
  catch (e: Exception) {
    println("Failed to parse command line options: ${e.message}")
    Args.usage()
    return
  }

  try {
    args.main()
  }
  catch (t: Throwable) {
    println("Unexpected failure. ${t.message}")
    t.printStackTrace()
    exitProcess(1)
  }
}

private val toolVersion: String by lazy {
  Args::class.java.getResource("/META-INF/cdn-layout-tool-version.txt")?.readText() ?: "dev"
}

private fun Args.main() {
  val masterPlan = planCdnUpload(this@main, emptyCdnSnapshot(), localCdnSnapshot(indexesDir))
  wipeFiles(indexesDir, masterPlan.removeEntries)
  addFiles(indexesDir, masterPlan.newEntries)
}
